@@ -34,19 +34,21 @@ class TestStableRequestCheck(ReportTestCase):
         self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'main'])
         self.child_repo = make_repo(self.child_git_repo.path)
 
-    def init_check(self, options=None, future=0):
-        self.options = options if options is not None else self._options()
+    def init_check(self, options=None, future=0, stable_time=None):
+        self.options = options if options is not None else self._options(stable_time=stable_time)
         self.check, required_addons, self.source = init_check(self.check_kls, self.options)
         for k, v in required_addons.items():
             setattr(self, k, v)
         if future:
             self.check.today = datetime.today() + timedelta(days=+future)
 
-    def _options(self, **kwargs):
+    def _options(self, stable_time=None, **kwargs):
         args = [
             'scan', '-q', '--cache-dir', self.cache_dir,
             '--repo', self.child_repo.location,
         ]
+        if stable_time is not None:
+            args.extend(['--stabletime', str(stable_time)])
         options, _ = self._tool.parse_args(args)
         return options
 
@@ -73,7 +75,14 @@ class TestStableRequestCheck(ReportTestCase):
         self.init_check(future=30)
         self.assertNoReport(self.check, self.source)
 
-    def test_existing_stable_keywords(self):
+    @pytest.mark.parametrize(("stable_time", "less_days", "more_days"), (
+        pytest.param(None,  (0, 1, 10, 20, 29), (30, 31),     id="stable_time=unset"),
+        pytest.param(1,     (0,),               (1, 10),      id="stable_time=1"),
+        pytest.param(14,    (0, 1, 10, 13),     (14, 15, 30), id="stable_time=14"),
+        pytest.param(30,    (0, 1, 10, 20, 29), (30, 31),     id="stable_time=30"),
+        pytest.param(100,   (98, 99),           (100, 101),   id="stable_time=100"),
+    ))
+    def test_existing_stable_keywords(self, stable_time, less_days, more_days):
         self.parent_repo.create_ebuild('cat/pkg-1', keywords=['amd64'])
         self.parent_git_repo.add_all('cat/pkg-1')
         self.parent_repo.create_ebuild('cat/pkg-2', keywords=['~amd64'])
@@ -81,15 +90,16 @@ class TestStableRequestCheck(ReportTestCase):
         self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
 
         # packages are not old enough to trigger any results
-        for days in (0, 1, 10, 20, 29):
-            self.init_check(future=days)
-            self.assertNoReport(self.check, self.source)
+        for future in less_days:
+            self.init_check(future=future, stable_time=stable_time)
+            self.assertNoReport(self.check, self.source, msg=f"Got report for future={future}")
 
-        # packages are now >= 30 days old
-        self.init_check(future=30)
-        r = self.assertReport(self.check, self.source)
-        expected = StableRequest('0', ['~amd64'], 30, pkg=VersionedCPV('cat/pkg-2'))
-        assert r == expected
+        # packages are now >= stable_time days old
+        for future in more_days:
+            self.init_check(future=future, stable_time=stable_time)
+            r = self.assertReport(self.check, self.source)
+            expected = StableRequest('0', ['~amd64'], future, pkg=VersionedCPV('cat/pkg-2'))
+            assert r == expected
 
     def test_multislot_with_unstable_slot(self):
         self.parent_repo.create_ebuild('cat/pkg-1', keywords=['amd64'])
